@@ -9,7 +9,7 @@ More modifications by Jeff Whitaker
 
 typedef struct { float r, i; } f2c_complex;
 typedef struct { double r, i; } f2c_doublecomplex;
-typedef long int (*L_fp)();
+/* typedef long int (*L_fp)(); */
 
 static PyObject *ErrorObject;
 
@@ -50,14 +50,13 @@ static int lapack_lite_CheckObject(PyObject *ob, int t, char *obname,
     return 1;
 }
 
-#define LDATA(p) ((long int *) (((PyArrayObject *)p)->data))
 #define CHDATA(p) ((char *) (((PyArrayObject *)p)->data))
 #define SHDATA(p) ((short int *) (((PyArrayObject *)p)->data))
 #define DDATA(p) ((double *) (((PyArrayObject *)p)->data))
 #define FDATA(p) ((float *) (((PyArrayObject *)p)->data))
 #define CDATA(p) ((f2c_complex *) (((PyArrayObject *)p)->data))
 #define ZDATA(p) ((f2c_doublecomplex *) (((PyArrayObject *)p)->data))
-
+#define IDATA(p) ((int *) (((PyArrayObject *)p)->data))
 
 
 
@@ -66,19 +65,19 @@ static PyObject *lapack_lite_dgeev(PyObject *self, PyObject *args)
 int  lapack_lite_status__;
 char jobvl;
 char jobvr;
-long int n;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *wr;
 PyObject *wi;
 PyObject *vl;
-long int ldvl;
+int ldvl;
 PyObject *vr;
-long int ldvr;
+int ldvr;
 PyObject *work;
-long int lwork;
-long int info;
-TRY(PyArg_ParseTuple(args,"cclOlOOOlOlOll",&jobvl,&jobvr,&n,&a,&lda,&wr,&wi,&vl,&ldvl,&vr,&ldvr,&work,&lwork,&info));
+int lwork;
+int info;
+TRY(PyArg_ParseTuple(args,"cciOiOOOiOiOii",&jobvl,&jobvr,&n,&a,&lda,&wr,&wi,&vl,&ldvl,&vr,&ldvr,&work,&lwork,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_DOUBLE,"a","PyArray_DOUBLE","dgeev")); 
 TRY(lapack_lite_CheckObject(wr,PyArray_DOUBLE,"wr","PyArray_DOUBLE","dgeev")); 
@@ -94,7 +93,7 @@ lapack_lite_status__ = dgeev(&jobvl,&jobvr,&n,DDATA(a),&lda,DDATA(wr),DDATA(wi),
 lapack_lite_status__ = dgeev_(&jobvl,&jobvr,&n,DDATA(a),&lda,DDATA(wr),DDATA(wi),DDATA(vl),&ldvl,DDATA(vr),&ldvr,DDATA(work),&lwork,&info);
 #endif
 
-return Py_BuildValue("{s:l,s:c,s:c,s:l,s:l,s:l,s:l,s:l,s:l}","dgeev_",lapack_lite_status__,"jobvl",jobvl,"jobvr",jobvr,"n",n,"lda",lda,"ldvl",ldvl,"ldvr",ldvr,"lwork",lwork,"info",info);
+return Py_BuildValue("{s:i,s:c,s:c,s:i,s:i,s:i,s:i,s:i,s:i}","dgeev_",lapack_lite_status__,"jobvl",jobvl,"jobvr",jobvr,"n",n,"lda",lda,"ldvl",ldvl,"ldvr",ldvr,"lwork",lwork,"info",info);
 }
 
 
@@ -114,7 +113,7 @@ static PyObject *lapack_lite_dsyevd(PyObject *self, PyObject *args)
   /*          = 'U':  Upper triangle of A is stored; */
   /*          = 'L':  Lower triangle of A is stored. */
   
-  long int n;
+  int n;
   /*  N       (input) INTEGER */
   /*          The order of the matrix A.  N >= 0. */
   
@@ -131,7 +130,7 @@ static PyObject *lapack_lite_dsyevd(PyObject *self, PyObject *args)
   /*          or the upper triangle (if UPLO='U') of A, including the */
   /*          diagonal, is destroyed. */
   
-  long int lda;
+  int lda;
   /*  LDA     (input) INTEGER */
   /*          The leading dimension of the array A.  LDA >= max(1,N). */
   
@@ -143,16 +142,16 @@ static PyObject *lapack_lite_dsyevd(PyObject *self, PyObject *args)
   /*  WORK    (workspace/output) DOUBLE PRECISION array, dimension (LWORK) */
   /*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
 
-  long int lwork;
+  int lwork;
   /*  LWORK   (input) INTEGER */
   /*          The length of the array WORK.  LWORK >= max(1,3*N-1). */
   /*          For optimal efficiency, LWORK >= (NB+2)*N, */
   /*          where NB is the blocksize for DSYTRD returned by ILAENV. */
 
   PyObject *iwork;
-  long int liwork;
+  int liwork;
   
-  long int info;
+  int info;
   /*  INFO    (output) INTEGER */
   /*          = 0:  successful exit */
   /*          < 0:  if INFO = -i, the i-th argument had an illegal value */
@@ -167,21 +166,21 @@ static PyObject *lapack_lite_dsyevd(PyObject *self, PyObject *args)
 
 
   
-  TRY(PyArg_ParseTuple(args,"cclOlOOlOll",&jobz,&uplo,&n,&a,&lda,&w,&work,&lwork,&iwork,&liwork,&info));
+  TRY(PyArg_ParseTuple(args,"cciOiOOiOii",&jobz,&uplo,&n,&a,&lda,&w,&work,&lwork,&iwork,&liwork,&info));
 
   TRY(lapack_lite_CheckObject(a,PyArray_DOUBLE,"a","PyArray_DOUBLE","dsyevd")); 
   TRY(lapack_lite_CheckObject(w,PyArray_DOUBLE,"w","PyArray_DOUBLE","dsyevd")); 
   TRY(lapack_lite_CheckObject(work,PyArray_DOUBLE,"work","PyArray_DOUBLE","dsyevd")); 
-  TRY(lapack_lite_CheckObject(iwork,PyArray_LONG,"iwork","PyArray_LONG","dsyevd")); 
+  TRY(lapack_lite_CheckObject(iwork,PyArray_INT,"iwork","PyArray_INT","dsyevd")); 
   
   
 #if defined(NO_APPEND_FORTRAN)
-  lapack_lite_status__ = dsyevd(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,LDATA(iwork),&liwork,&info);
+  lapack_lite_status__ = dsyevd(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,IDATA(iwork),&liwork,&info);
 #else
-  lapack_lite_status__ = dsyevd_(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,LDATA(iwork),&liwork,&info);
+  lapack_lite_status__ = dsyevd_(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,IDATA(iwork),&liwork,&info);
 #endif
   
-  return Py_BuildValue("{s:l,s:c,s:c,s:l,s:l,s:l,s:l,s:l}","dsyevd_",lapack_lite_status__,"jobz",jobz,"uplo",uplo,"n",n,"lda",lda,"lwork",lwork,"liwork",liwork,"info",info);
+  return Py_BuildValue("{s:i,s:c,s:c,s:i,s:i,s:i,s:i,s:i}","dsyevd_",lapack_lite_status__,"jobz",jobz,"uplo",uplo,"n",n,"lda",lda,"lwork",lwork,"liwork",liwork,"info",info);
   
   
 }
@@ -201,7 +200,7 @@ static PyObject *lapack_lite_zheevd(PyObject *self, PyObject *args)
   /*          = 'U':  Upper triangle of A is stored; */
   /*          = 'L':  Lower triangle of A is stored. */
   
-  long int n;
+  int n;
   /*  N       (input) INTEGER */
   /*          The order of the matrix A.  N >= 0. */
   
@@ -218,7 +217,7 @@ static PyObject *lapack_lite_zheevd(PyObject *self, PyObject *args)
   /*          or the upper triangle (if UPLO='U') of A, including the */
   /*          diagonal, is destroyed. */
   
-  long int lda;
+  int lda;
   /*  LDA     (input) INTEGER */
   /*          The leading dimension of the array A.  LDA >= max(1,N). */
   
@@ -230,7 +229,7 @@ static PyObject *lapack_lite_zheevd(PyObject *self, PyObject *args)
   /*  WORK    (workspace/output) COMPLEX*16 array, dimension (LWORK) */
   /*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
 
-  long int lwork;
+  int lwork;
   /*  LWORK   (input) INTEGER */
   /*          The length of the array WORK.  LWORK >= max(1,3*N-1). */
   /*          For optimal efficiency, LWORK >= (NB+2)*N, */
@@ -238,12 +237,12 @@ static PyObject *lapack_lite_zheevd(PyObject *self, PyObject *args)
   
   PyObject *rwork;
   /*  RWORK   (workspace) DOUBLE PRECISION array, dimension (max(1, 3*N-2)) */
-  long int lrwork;
+  int lrwork;
 
   PyObject *iwork;
-  long int liwork;
+  int liwork;
   
-  long int info;
+  int info;
   /*  INFO    (output) INTEGER */
   /*          = 0:  successful exit */
   /*          < 0:  if INFO = -i, the i-th argument had an illegal value */
@@ -258,22 +257,22 @@ static PyObject *lapack_lite_zheevd(PyObject *self, PyObject *args)
 
 
   
-  TRY(PyArg_ParseTuple(args,"cclOlOOlOlOll",&jobz,&uplo,&n,&a,&lda,&w,&work,&lwork,&rwork,&lrwork,&iwork,&liwork,&info));
+  TRY(PyArg_ParseTuple(args,"cciOiOOiOiOii",&jobz,&uplo,&n,&a,&lda,&w,&work,&lwork,&rwork,&lrwork,&iwork,&liwork,&info));
 
   TRY(lapack_lite_CheckObject(a,PyArray_CDOUBLE,"a","PyArray_CDOUBLE","zheevd")); 
   TRY(lapack_lite_CheckObject(w,PyArray_DOUBLE,"w","PyArray_DOUBLE","zheevd")); 
   TRY(lapack_lite_CheckObject(work,PyArray_CDOUBLE,"work","PyArray_CDOUBLE","zheevd")); 
   TRY(lapack_lite_CheckObject(w,PyArray_DOUBLE,"rwork","PyArray_DOUBLE","zheevd")); 
-  TRY(lapack_lite_CheckObject(iwork,PyArray_LONG,"iwork","PyArray_LONG","zheevd")); 
+  TRY(lapack_lite_CheckObject(iwork,PyArray_INT,"iwork","PyArray_INT","zheevd")); 
   
   
 #if defined(NO_APPEND_FORTRAN)
-  lapack_lite_status__ = zheevd(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,DDATA(rwork),&lrwork,LDATA(iwork),&liwork,&info);
+  lapack_lite_status__ = zheevd(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,DDATA(rwork),&lrwork,IDATA(iwork),&liwork,&info);
 #else
-  lapack_lite_status__ = zheevd_(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,DDATA(rwork),&lrwork,LDATA(iwork),&liwork,&info);
+  lapack_lite_status__ = zheevd_(&jobz,&uplo,&n,DDATA(a),&lda,DDATA(w),DDATA(work),&lwork,DDATA(rwork),&lrwork,IDATA(iwork),&liwork,&info);
 #endif
   
-  return Py_BuildValue("{s:l,s:c,s:c,s:l,s:l,s:l,s:l,s:l,s:l}","zheevd_",lapack_lite_status__,"jobz",jobz,"uplo",uplo,"n",n,"lda",lda,"lwork",lwork,"lrwork",lrwork,"liwork",liwork,"info",info);
+  return Py_BuildValue("{s:i,s:c,s:c,s:i,s:i,s:i,s:i,s:i,s:i}","zheevd_",lapack_lite_status__,"jobz",jobz,"uplo",uplo,"n",n,"lda",lda,"lwork",lwork,"lrwork",lrwork,"liwork",liwork,"info",info);
   
   
 }
@@ -282,36 +281,36 @@ static PyObject *lapack_lite_zheevd(PyObject *self, PyObject *args)
 static PyObject *lapack_lite_dgelsd(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int m;
-long int n;
-long int nrhs;
+int m;
+int n;
+int nrhs;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *b;
-long int ldb;
+int ldb;
 PyObject *s;
 double rcond;
-long int rank;
+int rank;
 PyObject *work;
 PyObject *iwork;
-long int lwork;
-long int info;
-TRY(PyArg_ParseTuple(args,"lllOlOlOdlOlOl",&m,&n,&nrhs,&a,&lda,&b,&ldb,&s,&rcond,&rank,&work,&lwork,&iwork,&info));
+int lwork;
+int info;
+TRY(PyArg_ParseTuple(args,"iiiOiOiOdiOiOi",&m,&n,&nrhs,&a,&lda,&b,&ldb,&s,&rcond,&rank,&work,&lwork,&iwork,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_DOUBLE,"a","PyArray_DOUBLE","dgelsd")); 
 TRY(lapack_lite_CheckObject(b,PyArray_DOUBLE,"b","PyArray_DOUBLE","dgelsd")); 
 TRY(lapack_lite_CheckObject(s,PyArray_DOUBLE,"s","PyArray_DOUBLE","dgelsd")); 
 TRY(lapack_lite_CheckObject(work,PyArray_DOUBLE,"work","PyArray_DOUBLE","dgelsd")); 
-TRY(lapack_lite_CheckObject(iwork,PyArray_LONG,"iwork","PyArray_LONG","dgelsd")); 
+TRY(lapack_lite_CheckObject(iwork,PyArray_INT,"iwork","PyArray_INT","dgelsd")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
-lapack_lite_status__ = dgelsd(&m,&n,&nrhs,DDATA(a),&lda,DDATA(b),&ldb,DDATA(s),&rcond,&rank,DDATA(work),&lwork,LDATA(iwork),&info);
+lapack_lite_status__ = dgelsd(&m,&n,&nrhs,DDATA(a),&lda,DDATA(b),&ldb,DDATA(s),&rcond,&rank,DDATA(work),&lwork,IDATA(iwork),&info);
 #else
-lapack_lite_status__ = dgelsd_(&m,&n,&nrhs,DDATA(a),&lda,DDATA(b),&ldb,DDATA(s),&rcond,&rank,DDATA(work),&lwork,LDATA(iwork),&info);
+lapack_lite_status__ = dgelsd_(&m,&n,&nrhs,DDATA(a),&lda,DDATA(b),&ldb,DDATA(s),&rcond,&rank,DDATA(work),&lwork,IDATA(iwork),&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l,s:l,s:d,s:l,s:l,s:l}","dgelsd_",lapack_lite_status__,"m",m,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"rcond",rcond,"rank",rank,"lwork",lwork,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i,s:i,s:i,s:d,s:i,s:i,s:i}","dgelsd_",lapack_lite_status__,"m",m,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"rcond",rcond,"rank",rank,"lwork",lwork,"info",info);
 }
 
 
@@ -321,28 +320,28 @@ return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l,s:l,s:d,s:l,s:l,s:l}","dgelsd_",lapac
 static PyObject *lapack_lite_dgesv(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int n;
-long int nrhs;
+int n;
+int nrhs;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *ipiv;
 PyObject *b;
-long int ldb;
-long int info;
-TRY(PyArg_ParseTuple(args,"llOlOOll",&n,&nrhs,&a,&lda,&ipiv,&b,&ldb,&info));
+int ldb;
+int info;
+TRY(PyArg_ParseTuple(args,"iiOiOOii",&n,&nrhs,&a,&lda,&ipiv,&b,&ldb,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_DOUBLE,"a","PyArray_DOUBLE","dgesv")); 
-TRY(lapack_lite_CheckObject(ipiv,PyArray_LONG,"ipiv","PyArray_LONG","dgesv")); 
+TRY(lapack_lite_CheckObject(ipiv,PyArray_INT,"ipiv","PyArray_INT","dgesv")); 
 TRY(lapack_lite_CheckObject(b,PyArray_DOUBLE,"b","PyArray_DOUBLE","dgesv")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
-lapack_lite_status__ = dgesv(&n,&nrhs,DDATA(a),&lda,LDATA(ipiv),DDATA(b),&ldb,&info);
+lapack_lite_status__ = dgesv(&n,&nrhs,DDATA(a),&lda,IDATA(ipiv),DDATA(b),&ldb,&info);
 #else
-lapack_lite_status__ = dgesv_(&n,&nrhs,DDATA(a),&lda,LDATA(ipiv),DDATA(b),&ldb,&info);
+lapack_lite_status__ = dgesv_(&n,&nrhs,DDATA(a),&lda,IDATA(ipiv),DDATA(b),&ldb,&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l,s:l}","dgesv_",lapack_lite_status__,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i,s:i,s:i}","dgesv_",lapack_lite_status__,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"info",info);
 }
 
 
@@ -353,36 +352,36 @@ static PyObject *lapack_lite_dgesdd(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
 char jobz;
-long int m;
-long int n;
+int m;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *s;
 PyObject *u;
-long int ldu;
+int ldu;
 PyObject *vt;
-long int ldvt;
+int ldvt;
 PyObject *work;
-long int lwork;
+int lwork;
 PyObject *iwork;
-long int info;
-TRY(PyArg_ParseTuple(args,"cllOlOOlOlOlOl",&jobz,&m,&n,&a,&lda,&s,&u,&ldu,&vt,&ldvt,&work,&lwork,&iwork,&info));
+int info;
+TRY(PyArg_ParseTuple(args,"ciiOiOOiOiOiOi",&jobz,&m,&n,&a,&lda,&s,&u,&ldu,&vt,&ldvt,&work,&lwork,&iwork,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_DOUBLE,"a","PyArray_DOUBLE","dgesdd")); 
 TRY(lapack_lite_CheckObject(s,PyArray_DOUBLE,"s","PyArray_DOUBLE","dgesdd")); 
 TRY(lapack_lite_CheckObject(u,PyArray_DOUBLE,"u","PyArray_DOUBLE","dgesdd")); 
 TRY(lapack_lite_CheckObject(vt,PyArray_DOUBLE,"vt","PyArray_DOUBLE","dgesdd")); 
 TRY(lapack_lite_CheckObject(work,PyArray_DOUBLE,"work","PyArray_DOUBLE","dgesdd")); 
-TRY(lapack_lite_CheckObject(iwork,PyArray_LONG,"iwork","PyArray_LONG","dgesdd")); 
+TRY(lapack_lite_CheckObject(iwork,PyArray_INT,"iwork","PyArray_INT","dgesdd")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
 lapack_lite_status__ = dgesdd(&jobz,&m,&n,DDATA(a),&lda,DDATA(s),DDATA(u),&ldu,DDATA(vt),&ldvt,DDATA(work),&lwork,&iwork,&info);
 #else
-lapack_lite_status__ = dgesdd_(&jobz,&m,&n,DDATA(a),&lda,DDATA(s),DDATA(u),&ldu,DDATA(vt),&ldvt,DDATA(work),&lwork,LDATA(iwork),&info);
+lapack_lite_status__ = dgesdd_(&jobz,&m,&n,DDATA(a),&lda,DDATA(s),DDATA(u),&ldu,DDATA(vt),&ldvt,DDATA(work),&lwork,IDATA(iwork),&info);
 #endif
 
-return Py_BuildValue("{s:l,s:c,s:l,s:l,s:l,s:l,s:l,s:l,s:l}","dgesdd_",lapack_lite_status__,"jobz",jobz,"m",m,"n",n,"lda",lda,"ldu",ldu,"ldvt",ldvt,"lwork",lwork,"info",info);
+return Py_BuildValue("{s:i,s:c,s:i,s:i,s:i,s:i,s:i,s:i,s:i}","dgesdd_",lapack_lite_status__,"jobz",jobz,"m",m,"n",n,"lda",lda,"ldu",ldu,"ldvt",ldvt,"lwork",lwork,"info",info);
 }
 
 
@@ -390,37 +389,37 @@ return Py_BuildValue("{s:l,s:c,s:l,s:l,s:l,s:l,s:l,s:l,s:l}","dgesdd_",lapack_li
 static PyObject *lapack_lite_dgetrf(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int m;
-long int n;
+int m;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *ipiv;
-long int info;
-TRY(PyArg_ParseTuple(args,"llOlOl",&m,&n,&a,&lda,&ipiv,&info));
+int info;
+TRY(PyArg_ParseTuple(args,"iiOiOi",&m,&n,&a,&lda,&ipiv,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_DOUBLE,"a","PyArray_DOUBLE","dgetrf")); 
-TRY(lapack_lite_CheckObject(ipiv,PyArray_LONG,"ipiv","PyArray_LONG","dgetrf")); 
+TRY(lapack_lite_CheckObject(ipiv,PyArray_INT,"ipiv","PyArray_INT","dgetrf")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
-lapack_lite_status__ = dgetrf(&m,&n,DDATA(a),&lda,LDATA(ipiv),&info);
+lapack_lite_status__ = dgetrf(&m,&n,DDATA(a),&lda,IDATA(ipiv),&info);
 #else
-lapack_lite_status__ = dgetrf_(&m,&n,DDATA(a),&lda,LDATA(ipiv),&info);
+lapack_lite_status__ = dgetrf_(&m,&n,DDATA(a),&lda,IDATA(ipiv),&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l}","dgetrf_",lapack_lite_status__,"m",m,"n",n,"lda",lda,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i,s:i}","dgetrf_",lapack_lite_status__,"m",m,"n",n,"lda",lda,"info",info);
 }
 
 static PyObject *lapack_lite_dpotrf(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int n;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 char uplo;
-long int info;
+int info;
 
-TRY(PyArg_ParseTuple(args,"clOll",&uplo,&n,&a,&lda,&info));
+TRY(PyArg_ParseTuple(args,"ciOii",&uplo,&n,&a,&lda,&info));
 TRY(lapack_lite_CheckObject(a,PyArray_DOUBLE,"a","PyArray_DOUBLE","dpotrf")); 
 
 #if defined(NO_APPEND_FORTRAN)
@@ -429,7 +428,7 @@ lapack_lite_status__ = dpotrf(&uplo,&n,DDATA(a),&lda,&info);
 lapack_lite_status__ = dpotrf_(&uplo,&n,DDATA(a),&lda,&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l}","dpotrf_",lapack_lite_status__,"n",n,"lda",lda,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i}","dpotrf_",lapack_lite_status__,"n",n,"lda",lda,"info",info);
 }
  
 static PyObject *lapack_lite_zgeev(PyObject *self, PyObject *args)
@@ -437,19 +436,19 @@ static PyObject *lapack_lite_zgeev(PyObject *self, PyObject *args)
 int  lapack_lite_status__;
 char jobvl;
 char jobvr;
-long int n;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *w;
 PyObject *vl;
-long int ldvl;
+int ldvl;
 PyObject *vr;
-long int ldvr;
+int ldvr;
 PyObject *work;
-long int lwork;
+int lwork;
 PyObject *rwork;
-long int info;
-TRY(PyArg_ParseTuple(args,"cclOlOOlOlOlOl",&jobvl,&jobvr,&n,&a,&lda,&w,&vl,&ldvl,&vr,&ldvr,&work,&lwork,&rwork,&info));
+int info;
+TRY(PyArg_ParseTuple(args,"cciOiOOiOiOiOi",&jobvl,&jobvr,&n,&a,&lda,&w,&vl,&ldvl,&vr,&ldvr,&work,&lwork,&rwork,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_CDOUBLE,"a","PyArray_CDOUBLE","zgeev")); 
 TRY(lapack_lite_CheckObject(w,PyArray_CDOUBLE,"w","PyArray_CDOUBLE","zgeev")); 
@@ -465,7 +464,7 @@ lapack_lite_status__ = zgeev(&jobvl,&jobvr,&n,ZDATA(a),&lda,ZDATA(w),ZDATA(vl),&
 lapack_lite_status__ = zgeev_(&jobvl,&jobvr,&n,ZDATA(a),&lda,ZDATA(w),ZDATA(vl),&ldvl,ZDATA(vr),&ldvr,ZDATA(work),&lwork,DDATA(rwork),&info);
 #endif
 
-return Py_BuildValue("{s:l,s:c,s:c,s:l,s:l,s:l,s:l,s:l,s:l}","zgeev_",lapack_lite_status__,"jobvl",jobvl,"jobvr",jobvr,"n",n,"lda",lda,"ldvl",ldvl,"ldvr",ldvr,"lwork",lwork,"info",info);
+return Py_BuildValue("{s:i,s:c,s:c,s:i,s:i,s:i,s:i,s:i,s:i}","zgeev_",lapack_lite_status__,"jobvl",jobvl,"jobvr",jobvr,"n",n,"lda",lda,"ldvl",ldvl,"ldvr",ldvr,"lwork",lwork,"info",info);
 }
 
 
@@ -474,38 +473,38 @@ return Py_BuildValue("{s:l,s:c,s:c,s:l,s:l,s:l,s:l,s:l,s:l}","zgeev_",lapack_lit
 static PyObject *lapack_lite_zgelsd(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int m;
-long int n;
-long int nrhs;
+int m;
+int n;
+int nrhs;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *b;
-long int ldb;
+int ldb;
 PyObject *s;
 double rcond;
-long int rank;
+int rank;
 PyObject *work;
-long int lwork;
+int lwork;
 PyObject *rwork;
 PyObject *iwork;
-long int info;
-TRY(PyArg_ParseTuple(args,"lllOlOlOdlOlOOl",&m,&n,&nrhs,&a,&lda,&b,&ldb,&s,&rcond,&rank,&work,&lwork,&rwork,&iwork,&info));
+int info;
+TRY(PyArg_ParseTuple(args,"iiiOiOiOdiOiOOi",&m,&n,&nrhs,&a,&lda,&b,&ldb,&s,&rcond,&rank,&work,&lwork,&rwork,&iwork,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_CDOUBLE,"a","PyArray_CDOUBLE","zgelsd")); 
 TRY(lapack_lite_CheckObject(b,PyArray_CDOUBLE,"b","PyArray_CDOUBLE","zgelsd")); 
 TRY(lapack_lite_CheckObject(s,PyArray_DOUBLE,"s","PyArray_DOUBLE","zgelsd")); 
 TRY(lapack_lite_CheckObject(work,PyArray_CDOUBLE,"work","PyArray_CDOUBLE","zgelsd")); 
 TRY(lapack_lite_CheckObject(rwork,PyArray_DOUBLE,"rwork","PyArray_DOUBLE","zgelsd")); 
-TRY(lapack_lite_CheckObject(iwork,PyArray_LONG,"iwork","PyArray_LONG","zgelsd")); 
+TRY(lapack_lite_CheckObject(iwork,PyArray_INT,"iwork","PyArray_INT","zgelsd")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
-lapack_lite_status__ = zgelsd(&m,&n,&nrhs,ZDATA(a),&lda,ZDATA(b),&ldb,DDATA(s),&rcond,&rank,ZDATA(work),&lwork,DDATA(rwork),LDATA(iwork),&info);
+lapack_lite_status__ = zgelsd(&m,&n,&nrhs,ZDATA(a),&lda,ZDATA(b),&ldb,DDATA(s),&rcond,&rank,ZDATA(work),&lwork,DDATA(rwork),IDATA(iwork),&info);
 #else
-lapack_lite_status__ = zgelsd_(&m,&n,&nrhs,ZDATA(a),&lda,ZDATA(b),&ldb,DDATA(s),&rcond,&rank,ZDATA(work),&lwork,DDATA(rwork),LDATA(iwork),&info);
+lapack_lite_status__ = zgelsd_(&m,&n,&nrhs,ZDATA(a),&lda,ZDATA(b),&ldb,DDATA(s),&rcond,&rank,ZDATA(work),&lwork,DDATA(rwork),IDATA(iwork),&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l,s:l,s:l,s:l,s:l}","zgelsd_",lapack_lite_status__,"m",m,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"rank",rank,"lwork",lwork,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i}","zgelsd_",lapack_lite_status__,"m",m,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"rank",rank,"lwork",lwork,"info",info);
 }
 
 
@@ -513,28 +512,28 @@ return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l,s:l,s:l,s:l,s:l}","zgelsd_",lapack_li
 static PyObject *lapack_lite_zgesv(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int n;
-long int nrhs;
+int n;
+int nrhs;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *ipiv;
 PyObject *b;
-long int ldb;
-long int info;
-TRY(PyArg_ParseTuple(args,"llOlOOll",&n,&nrhs,&a,&lda,&ipiv,&b,&ldb,&info));
+int ldb;
+int info;
+TRY(PyArg_ParseTuple(args,"iiOiOOii",&n,&nrhs,&a,&lda,&ipiv,&b,&ldb,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_CDOUBLE,"a","PyArray_CDOUBLE","zgesv")); 
-TRY(lapack_lite_CheckObject(ipiv,PyArray_LONG,"ipiv","PyArray_LONG","zgesv")); 
+TRY(lapack_lite_CheckObject(ipiv,PyArray_INT,"ipiv","PyArray_INT","zgesv")); 
 TRY(lapack_lite_CheckObject(b,PyArray_CDOUBLE,"b","PyArray_CDOUBLE","zgesv")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
-lapack_lite_status__ = zgesv(&n,&nrhs,ZDATA(a),&lda,LDATA(ipiv),ZDATA(b),&ldb,&info);
+lapack_lite_status__ = zgesv(&n,&nrhs,ZDATA(a),&lda,IDATA(ipiv),ZDATA(b),&ldb,&info);
 #else
-lapack_lite_status__ = zgesv_(&n,&nrhs,ZDATA(a),&lda,LDATA(ipiv),ZDATA(b),&ldb,&info);
+lapack_lite_status__ = zgesv_(&n,&nrhs,ZDATA(a),&lda,IDATA(ipiv),ZDATA(b),&ldb,&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l,s:l}","zgesv_",lapack_lite_status__,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i,s:i,s:i}","zgesv_",lapack_lite_status__,"n",n,"nrhs",nrhs,"lda",lda,"ldb",ldb,"info",info);
 }
 
 
@@ -545,21 +544,21 @@ static PyObject *lapack_lite_zgesdd(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
 char jobz;
-long int m;
-long int n;
+int m;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *s;
 PyObject *u;
-long int ldu;
+int ldu;
 PyObject *vt;
-long int ldvt;
+int ldvt;
 PyObject *work;
-long int lwork;
+int lwork;
 PyObject *rwork;
 PyObject *iwork;
-long int info;
-TRY(PyArg_ParseTuple(args,"cllOlOOlOlOlOOl",&jobz,&m,&n,&a,&lda,&s,&u,&ldu,&vt,&ldvt,&work,&lwork,&rwork,&iwork,&info));
+int info;
+TRY(PyArg_ParseTuple(args,"ciiOiOOiOiOiOOi",&jobz,&m,&n,&a,&lda,&s,&u,&ldu,&vt,&ldvt,&work,&lwork,&rwork,&iwork,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_CDOUBLE,"a","PyArray_CDOUBLE","zgesdd")); 
 TRY(lapack_lite_CheckObject(s,PyArray_DOUBLE,"s","PyArray_DOUBLE","zgesdd")); 
@@ -567,16 +566,16 @@ TRY(lapack_lite_CheckObject(u,PyArray_CDOUBLE,"u","PyArray_CDOUBLE","zgesdd"));
 TRY(lapack_lite_CheckObject(vt,PyArray_CDOUBLE,"vt","PyArray_CDOUBLE","zgesdd")); 
 TRY(lapack_lite_CheckObject(work,PyArray_CDOUBLE,"work","PyArray_CDOUBLE","zgesdd")); 
 TRY(lapack_lite_CheckObject(rwork,PyArray_DOUBLE,"rwork","PyArray_DOUBLE","zgesdd")); 
-TRY(lapack_lite_CheckObject(iwork,PyArray_LONG,"iwork","PyArray_LONG","zgesdd")); 
+TRY(lapack_lite_CheckObject(iwork,PyArray_INT,"iwork","PyArray_INT","zgesdd")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
-lapack_lite_status__ = zgesdd(&jobz,&m,&n,ZDATA(a),&lda,DDATA(s),ZDATA(u),&ldu,ZDATA(vt),&ldvt,ZDATA(work),&lwork,DDATA(rwork),LDATA(iwork),&info);
+lapack_lite_status__ = zgesdd(&jobz,&m,&n,ZDATA(a),&lda,DDATA(s),ZDATA(u),&ldu,ZDATA(vt),&ldvt,ZDATA(work),&lwork,DDATA(rwork),IDATA(iwork),&info);
 #else
-lapack_lite_status__ = zgesdd_(&jobz,&m,&n,ZDATA(a),&lda,DDATA(s),ZDATA(u),&ldu,ZDATA(vt),&ldvt,ZDATA(work),&lwork,DDATA(rwork),LDATA(iwork),&info);
+lapack_lite_status__ = zgesdd_(&jobz,&m,&n,ZDATA(a),&lda,DDATA(s),ZDATA(u),&ldu,ZDATA(vt),&ldvt,ZDATA(work),&lwork,DDATA(rwork),IDATA(iwork),&info);
 #endif
 
-return Py_BuildValue("{s:l,s:c,s:l,s:l,s:l,s:l,s:l,s:l,s:l}","zgesdd_",lapack_lite_status__,"jobz",jobz,"m",m,"n",n,"lda",lda,"ldu",ldu,"ldvt",ldvt,"lwork",lwork,"info",info);
+return Py_BuildValue("{s:i,s:c,s:i,s:i,s:i,s:i,s:i,s:i,s:i}","zgesdd_",lapack_lite_status__,"jobz",jobz,"m",m,"n",n,"lda",lda,"ldu",ldu,"ldvt",ldvt,"lwork",lwork,"info",info);
 }
 
 
@@ -585,37 +584,37 @@ return Py_BuildValue("{s:l,s:c,s:l,s:l,s:l,s:l,s:l,s:l,s:l}","zgesdd_",lapack_li
 static PyObject *lapack_lite_zgetrf(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int m;
-long int n;
+int m;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 PyObject *ipiv;
-long int info;
-TRY(PyArg_ParseTuple(args,"llOlOl",&m,&n,&a,&lda,&ipiv,&info));
+int info;
+TRY(PyArg_ParseTuple(args,"iiOiOi",&m,&n,&a,&lda,&ipiv,&info));
 
 TRY(lapack_lite_CheckObject(a,PyArray_CDOUBLE,"a","PyArray_CDOUBLE","zgetrf")); 
-TRY(lapack_lite_CheckObject(ipiv,PyArray_LONG,"ipiv","PyArray_LONG","zgetrf")); 
+TRY(lapack_lite_CheckObject(ipiv,PyArray_INT,"ipiv","PyArray_INT","zgetrf")); 
 
 
 #if defined(NO_APPEND_FORTRAN)
-lapack_lite_status__ = zgetrf(&m,&n,ZDATA(a),&lda,LDATA(ipiv),&info);
+lapack_lite_status__ = zgetrf(&m,&n,ZDATA(a),&lda,IDATA(ipiv),&info);
 #else
-lapack_lite_status__ = zgetrf_(&m,&n,ZDATA(a),&lda,LDATA(ipiv),&info);
+lapack_lite_status__ = zgetrf_(&m,&n,ZDATA(a),&lda,IDATA(ipiv),&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l,s:l}","zgetrf_",lapack_lite_status__,"m",m,"n",n,"lda",lda,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i,s:i}","zgetrf_",lapack_lite_status__,"m",m,"n",n,"lda",lda,"info",info);
 }
 
 static PyObject *lapack_lite_zpotrf(PyObject *self, PyObject *args)
 {
 int  lapack_lite_status__;
-long int n;
+int n;
 PyObject *a;
-long int lda;
+int lda;
 char uplo;
-long int info;
+int info;
 
-TRY(PyArg_ParseTuple(args,"clOll",&uplo,&n,&a,&lda,&info));
+TRY(PyArg_ParseTuple(args,"ciOii",&uplo,&n,&a,&lda,&info));
 TRY(lapack_lite_CheckObject(a,PyArray_CDOUBLE,"a","PyArray_CDOUBLE","zpotrf")); 
 
 #if defined(NO_APPEND_FORTRAN)
@@ -624,7 +623,7 @@ lapack_lite_status__ = zpotrf(&uplo,&n,ZDATA(a),&lda,&info);
 lapack_lite_status__ = zpotrf_(&uplo,&n,ZDATA(a),&lda,&info);
 #endif
 
-return Py_BuildValue("{s:l,s:l,s:l,s:l}","zpotrf_",lapack_lite_status__,"n",n,"lda",lda,"info",info);
+return Py_BuildValue("{s:i,s:i,s:i,s:i}","zpotrf_",lapack_lite_status__,"n",n,"lda",lda,"info",info);
 }
 
 static struct PyMethodDef lapack_lite_module_methods[] = {
